/*
 * Copyright (c) 2005 Jakub Jermar
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup sparc64	
 * @{
 */
/** @file
 */

#include <arch/console.h>
#include <arch/types.h>

#include <arch/drivers/scr.h>
#include <arch/drivers/kbd.h>

#include <arch/drivers/sgcn.h>

#if defined (SUN4U)
	#ifdef CONFIG_Z8530
	#include <genarch/kbd/z8530.h>
	#endif
	#ifdef CONFIG_NS16550
	#include <genarch/kbd/ns16550.h>
	#endif
#elif defined (SUN4V)
	#include <arch/drivers/niagara.h>
#endif

#include <console/chardev.h>
#include <console/console.h>
#include <arch/asm.h>
#include <arch/register.h>
#include <proc/thread.h>
#include <arch/mm/tlb.h>
#include <genarch/ofw/ofw_tree.h>
#include <arch.h>
#include <panic.h>
#include <func.h>
#include <print.h>

#define KEYBOARD_POLL_PAUSE	50000	/* 50ms */

/** Kernel thread for polling keyboard.
 *
 * @param arg Ignored.
 */
void kkbdpoll(void *arg)
{
	thread_detach(THREAD);

#ifdef CONFIG_Z8530
	if (kbd_type == KBD_Z8530) {
		/*
		 * The z8530 driver is interrupt-driven.
		 */
		return;
	}
#endif

#ifdef CONFIG_NS16550
#ifdef CONFIG_NS16550_INTERRUPT_DRIVEN
	if (kbd_type == KBD_NS16550) {
		/*
		 * The ns16550 driver is interrupt-driven.
		 */
		return;
	}
#endif
#endif
	while (1) {
#ifdef CONFIG_NS16550
#ifndef CONFIG_NS16550_INTERRUPT_DRIVEN
		if (kbd_type == KBD_NS16550)
			ns16550_poll();
#endif
#endif
#ifdef CONFIG_SGCN
		if (kbd_type == KBD_SGCN)
			sgcn_poll();
#endif
#ifdef SUN4V
		if (kbd_type == KBD_SUN4V)
			niagara_poll();
#endif
		thread_usleep(KEYBOARD_POLL_PAUSE);
	}
}


/** @}
 */
